/*;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;		AVR m325 TestProgramm
;
;
;		CPU	ATMEGA325-PU
;			CLK=EXT X'tal(20MHz)
;			FuseH="D9" FuseL="FF" FuseE="FF"
;
;			
;		2012-06-19		c[H[Ec
;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;*/


#include <avr/io.h>



volatile static unsigned int	TIME;
volatile static unsigned char	HEXH,HEXL;




void TX(unsigned char TXD){

	while(!(UCSR0A & (1<<UDRE0)));
	UDR0 = TXD;

}



void Wait(void){					/* 1mS Timer */
	volatile int i;
	volatile unsigned char	rx;


	for(i=0; i<870; i++){
		if ((UCSR0A & 0x80) != 0){
			rx = UDR0;
			TX(rx);
		}
	}

}



void Timer(int Time){			/* mS Timer */
	volatile int i;

	for(i=0; i<Time; i++){
		Wait();
	}

}



unsigned char hex(unsigned char bin){

	bin &= 0x0f;					//O`PT
	if (bin < 10){
		bin = bin | 0x30;
	}
	else{
		bin = bin + 0x37;
	}

	return bin;
}



void bin_hex(unsigned char bin){	//Binary  2Hex(HEXH,HEXL)

	unsigned char hi,lo;

	hi = bin / 16;
	HEXH = hex(hi);
	lo = bin % 16;
	HEXL = hex(lo);
}



void TX_int(unsigned int DATA){
		bin_hex(DATA / 256);
		TX(HEXH);
		TX(HEXL);
		bin_hex(DATA & 0x00ff);
		TX(HEXH);
		TX(HEXL);
		TX(0x20);
}







void Init(void){			/*Initialize*/

	DDRA = 0xff;			//portA output
	PORTA = 0x00;
	DDRB = 0xff;			//portB output
	PORTB = 0x00;
	DDRC = 0xff;			//portC output
	PORTC = 0x00;
	DDRD = 0xff;			//portD output
	PORTD = 0x00;
	DDRE = 0xff;			//portE output
	PORTE = 0x00;
	DDRF = 0xff;			//portF output
	PORTF = 0x00;
	DDRG = 0xff;			//portG output
	PORTG = 0x00;

	Timer(50);

	UBRR0H = 0;				/*baud rate 9600*/
	UBRR0L = 129;			/*fosc/(16*baudrate) -1*/
	UCSR0C = 0x0e;			/*S8N2*/
	UCSR0B = 0x18;			/*TX & RX enable*/


	TIME = 0;

}





int main(){

	volatile int i;

	Init();

while(1){


	for(i=0; i<3; i++){

		Timer(2000);
		PORTA = 0xff;
		PORTB = 0xff;
		PORTC = 0xff;
		PORTD = 0xff;
		PORTE = 0xff;
		PORTF = 0xff;
		PORTG = 0xff;

		Timer(1000);
		PORTA = 0x00;
		PORTB = 0x00;
		PORTC = 0x00;
		PORTD = 0x00;
		PORTE = 0x00;
		PORTF = 0x00;
		PORTG = 0x00;

	}



	for(i=0; i<15; i++){

		Timer(200);
		PORTA = 0x55;
		PORTB = 0xaa;
		PORTC = 0x55;
		PORTD = 0x55;
		PORTE = 0xaa;
		PORTF = 0x55;
		PORTG = 0x55;

		Timer(200);
		PORTA = 0xaa;
		PORTB = 0x55;
		PORTC = 0xaa;
		PORTD = 0xaa;
		PORTE = 0x55;
		PORTF = 0xaa;
		PORTG = 0xaa;

		TX_int(i);
	}

}

}

